@@ -343,7 +343,10 @@ class Program(object):  # pragma: no cover
         Start the child program.
         """
         if not self.silent:
-            logger.info(f"🟩 Starting program: {self}\n environment = {self.env}")
+            msg = f"Starting program: {self}"
+            if self.env:
+                msg += f"\n environment = {self.env}"
+            logger.info(msg)
 
         self._T_start = now()
 
@@ -352,7 +355,7 @@ class Program(object):  # pragma: no cover
             self.args,
             stdout             = subprocess.PIPE,
             stderr             = subprocess.PIPE,
-            bufsize            = 1,
+            bufsize            = 0,
             close_fds          = False,
             env                = self.env,
             universal_newlines = False,
@@ -421,7 +424,7 @@ class Program(object):  # pragma: no cover
             self._watchdog_thread.join()
         self._return_code = self._proc.wait()
         if not self.silent:
-            logger.info("🟥 Program completed: %s --> %s" % (self, self._return_code))
+            logger.info("Program completed: %s --> %s" % (self, self._return_code))
         return self._return_code
 
     # --------------------------------------------------------------------------------------------------------------------
@@ -435,7 +438,7 @@ class Program(object):  # pragma: no cover
             The signal to send.
         """
         if not self.silent:
-            logger.info("🔥 Terminating program: %s with signal ⚡%s⚡" % (self, sig))
+            logger.info("Terminating program: %s with signal %s" % (self, sig))
         self._proc.send_signal(sig)
 
     # --------------------------------------------------------------------------------------------------------------------
@@ -444,7 +447,7 @@ class Program(object):  # pragma: no cover
         Terminate the child process by sending SIGTERM
         """
         if not self.silent:
-            logger.info("🔥 Terminating program: %s" % self)
+            logger.info("Terminating program: %s" % self)
         self._proc.terminate()
 
     # --------------------------------------------------------------------------------------------------------------------
